@@ -266,3 +266,15 @@ test_that("survey_total is correct with special chars in peel (se)",
                          filter(grp == "[320+](1)") %>%
                          .$tot_se))
 
+
+test_that("survey_mean gets percentage - each peel layer that adds up to one", {
+  dstrata <- apistrat %>%
+    as_survey_design(strata = stype, weights = pw)
+
+  results <- dstrata %>%
+    group_by(stype, awards) %>%
+    summarize(pct = survey_mean())
+
+  expect_equal(sum(results$pct), length(unique(results$stype)))
+  expect_equal(results$pct, c(0.27, 0.73, 0.68, 0.32, 0.52, 0.48))
+})
